#!/usr/bin/env python3

from argparse import Namespace
from pathlib import Path
from typing import Any

import tomllib

from .tree import SourceIndex, SourceNode


DEFAULT_TEMPLATE_DIRECTORY = ".dragonglass.tmpl"
DEFAULT_TEMPLATE_NAME = "default.html"


class Context:
    def __init__(self) -> None:
        self.source_dir: Path | None = None
        self.template_dir: Path | None = None
        self.config: dict[str, Any] = {}
        self.src_index: SourceIndex | None = None
        self.current_node: SourceNode | None = None
        self._default_template_name: str | None = None

    def load_config(self, args: Namespace) -> None:
        config_filename: str = str(args.config) if args.config else ".dragonglass"
        assert self.source_dir is not None
        config_path = self.source_dir / config_filename
        if config_path.exists() and config_path.is_file():
            with open(config_path, "rb") as f:
                self.config = tomllib.load(f)
        templates_section = self.config.get("templates", {})
        self.template_dir = self.source_dir / templates_section.get("directory", DEFAULT_TEMPLATE_DIRECTORY)
        self._default_template_name = templates_section.get("default", DEFAULT_TEMPLATE_NAME)

    @property
    def url_prefix(self) -> str:
        links_section = self.config.get("links", {})
        rc = links_section.get("prefix", "/")
        return rc if rc.endswith("/") else rc + '/'

    @property
    def relative_links(self) -> bool:
        links_section = self.config.get("links", {})
        return links_section.get("relative", False)

    def get_template_name_for_node(self, node: SourceNode) -> str:
        if not self.template_dir.is_dir():
            return DEFAULT_TEMPLATE_NAME
        return self._default_template_name
