#!/usr/bin/env python3

from jinja2 import Environment, BaseLoader, ChoiceLoader, FunctionLoader, FileSystemLoader

from .config import Context, DEFAULT_TEMPLATE_NAME

DEFAULT_TEMPLATE = """
<html>
    <head>
        <title>{{ title }}</title>
    </head>
    <body>
        <h1>{{ title }}</h1>
        {{ text }}
    </body>
</html>
"""


def _create_loader(ctxt: Context) -> BaseLoader:
    return ChoiceLoader([
        FileSystemLoader(ctxt.template_dir),
        FunctionLoader(lambda n: DEFAULT_TEMPLATE if n == DEFAULT_TEMPLATE_NAME else None)
    ])


def create_template_environment(ctxt: Context) -> Environment:
    return Environment(loader=_create_loader(ctxt))
